aboutsummaryrefslogtreecommitdiff
path: root/include/sound/hda_codec.h
diff options
context:
space:
mode:
authorGravatar Takashi Iwai <tiwai@suse.de> 2020-07-17 17:45:17 +0200
committerGravatar Takashi Iwai <tiwai@suse.de> 2020-07-20 10:10:47 +0200
commit9ab0cb309e7950a1649bffade985e7ccc7aaf675 (patch)
tree208c764fb84e0f8319a285c5f7de4f6f5936ef79 /include/sound/hda_codec.h
parentALSA: asihpi: delete duplicated word (diff)
downloadlinux-9ab0cb309e7950a1649bffade985e7ccc7aaf675.tar.gz
linux-9ab0cb309e7950a1649bffade985e7ccc7aaf675.tar.bz2
linux-9ab0cb309e7950a1649bffade985e7ccc7aaf675.zip
ALSA: Replace the word "slave" in vmaster API
Follow the recent inclusive terminology guidelines and replace the word "slave" in vmaster API. I chose the word "follower" at this time since it seems fitting for the purpose. Note that the word "master" is kept in API, since it refers rather to audio master volume control. Also, while we're at it, a typo in comments is corrected, too. Link: https://lore.kernel.org/r/20200717154517.27599-1-tiwai@suse.de Signed-off-by: Takashi Iwai <tiwai@suse.de>
Diffstat (limited to 'include/sound/hda_codec.h')
-rw-r--r--include/sound/hda_codec.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/include/sound/hda_codec.h b/include/sound/hda_codec.h
index d16a4229209b..f4cc364d837f 100644
--- a/include/sound/hda_codec.h
+++ b/include/sound/hda_codec.h
@@ -208,7 +208,7 @@ struct hda_codec {
struct mutex control_mutex;
struct snd_array spdif_out;
unsigned int spdif_in_enable; /* SPDIF input enable? */
- const hda_nid_t *slave_dig_outs; /* optional digital out slave widgets */
+ const hda_nid_t *follower_dig_outs; /* optional digital out follower widgets */
struct snd_array init_pins; /* initial (BIOS) pin configurations */
struct snd_array driver_pins; /* pin configs set by codec parser */
struct snd_array cvt_setups; /* audio convert setups */